@@ -36,10 +36,7 @@ sub new {
   return @_ ? $self->parse(@_) : $self;
 }
 
-sub all_text {
-  my $tree = shift->tree;
-  return _text(_elements($tree), 1, _trim($tree, @_));
-}
+sub all_text { shift->_content(1, @_) }
 
 sub append { shift->_add(1, @_) }
 
@@ -182,10 +179,7 @@ sub strip {
   return $self->_replace($tree, ['root', @{_elements($tree)}]);
 }
 
-sub text {
-  my $tree = shift->tree;
-  return _text(_elements($tree), 0, _trim($tree, @_));
-}
+sub text { shift->_content(0, @_) }
 
 sub text_after {
   my ($self, $trim) = @_;
@@ -244,6 +238,11 @@ sub _add {
   return $self;
 }
 
+sub _content {
+  my $tree = shift->tree;
+  return _text(_elements($tree), shift, _trim($tree, @_));
+}
+
 sub _elements {
   return [] unless my $e = shift;
   return [@$e[_offset($e) .. $#$e]];
@@ -614,7 +613,7 @@ element.
   $dom->parse('<div><h1>A</h1></div>')->at('h1')->replace('<h2>B</h2>');
 
   # "<div></div>"
-  $dom->parse('<div><h1>A</h1></div>')->at('h1')->replace('')->root;
+  $dom->parse('<div><h1>A</h1></div>')->at('h1')->replace('');
 
 =head2 replace_content
 
